@@ -31,6 +31,7 @@
 #include "xstuff.h"
 #include "panel-stock-icons.h"
 #include "panel-action-protocol.h"
+#include "panel-lockdown.h"
 
 #include "nothing.cP"
 
@@ -85,11 +86,11 @@ main (int argc, char **argv)
 			      NULL);
 
 	panel_global_config_load ();
+	panel_lockdown_init ();
 	panel_profile_load (profile_arg);
 
 	panel_session_init (argv [0]);
 
-
 	/*add forbidden lists to ALL panels*/
 	g_slist_foreach (panels,
 			 (GFunc)panel_widget_add_forbidden,
@@ -97,5 +98,7 @@ main (int argc, char **argv)
 
 	gtk_main ();
 
+	panel_lockdown_finalize ();
+
 	return 0;
 }
